pub struct CsvReader { /* private fields */ }Expand description
Zero-copy CSV parser for byte slices.
Fields are referenced as sub-slices of the original input and parsed in a single pass. Type inference is performed from the first data row.
Implementations